==> haskell-snap-core-1.0.3.2-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-Dqj7sbonFPn4tjBS73IYI7
key: snap-core-1.0.3.2-Dqj7sbonFPn4tjBS73IYI7
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 79bc5b2810f976ca468279dbc6aed72d
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-Dqj7sbonFPn4tjBS73IYI7
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 directory-1.3.1.5 filepath-1.4.2
    lifted-base-0.2.3.12-DiEMnZ6QT6930C48Uaxop5
    io-streams-1.5.0.1-4TKhhvq9gGzC2icTW4sVNs
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    monad-control-1.0.2.3-2M5i4nR3tZN58HK4Iovcf6 mtl-2.2.2
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx
    regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-71OkzG0c7DN1mT5seqZVLg
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             lifted-base-0.2.3.12-DiEMnZ6QT6930C48Uaxop5=790d1d186f6780eba20d2019e5126f80
             io-streams-1.5.0.1-4TKhhvq9gGzC2icTW4sVNs=a28989bac14c56155d8e2ad7235e055d
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             monad-control-1.0.2.3-2M5i4nR3tZN58HK4Iovcf6=426b8f9fb13500fce88d5a07e4a185fc
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx=cb9d840cfd21f0f57392c534369070bf
             regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe=eae15e0dc39513de0767dec8084921c8
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-71OkzG0c7DN1mT5seqZVLg=1413ad31d00a6763c36b63397e5c2714
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW=69b658fb7f59eb9acbefe047d83e7e11
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.3.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-AjEhzgQvde39rirAfXl6Wh
key: snap-core-1.0.3.2-AjEhzgQvde39rirAfXl6Wh
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 9338bf276a83dbc17a764f29ddb9db51
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-AjEhzgQvde39rirAfXl6Wh
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 directory-1.3.1.5 filepath-1.4.2
    lifted-base-0.2.3.12-BrYri3LWM9pJ2tWeaR9lDb
    io-streams-1.5.0.1-Axt1wq0YNM3Linfis9iVtB
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek mtl-2.2.2
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx
    regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-6FfBvmD6NTeAPSa47HXiSR
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             lifted-base-0.2.3.12-BrYri3LWM9pJ2tWeaR9lDb=d644bc8a6ccaa6c52fce0344d0467249
             io-streams-1.5.0.1-Axt1wq0YNM3Linfis9iVtB=042f420d0d36aae264f073533a6491ef
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek=4701eb7c70a10f72aec80f45872b6148
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx=cb9d840cfd21f0f57392c534369070bf
             regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe=eae15e0dc39513de0767dec8084921c8
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ=ff843a556414f5766b414ccfa8c6dff6
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             network-2.7.0.2-6FfBvmD6NTeAPSa47HXiSR=614b1a60f3013422c23df99507b7d70f
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
